==> cxf-services-xkms-common-3.3.11-sources.jar: org/apache/cxf/xkms/model/xkms/RecoverRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for RecoverRequestType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="RecoverRequestType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}RecoverKeyBinding"/&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/extension&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecoverRequestType", propOrder = {
    "recoverKeyBinding",
    "authentication"
})
public class RecoverRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "RecoverKeyBinding", required = true)
    protected KeyBindingType recoverKeyBinding = new KeyBindingType();
    @XmlElement(name = "Authentication", required = true)
    protected AuthenticationType authentication = new AuthenticationType();

    /**
     * Gets the value of the recoverKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingType }
     *     
     */
    public KeyBindingType getRecoverKeyBinding() {
        return recoverKeyBinding;
    }

    /**
     * Sets the value of the recoverKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingType }
     *     
     */
    public void setRecoverKeyBinding(KeyBindingType value) {
        this.recoverKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

}

==> cxf-services-xkms-common-3.4.10-sources.jar: org/apache/cxf/xkms/model/xkms/RecoverRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RecoverRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RecoverRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}RecoverKeyBinding"/&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}Authentication"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecoverRequestType", propOrder = {
    "recoverKeyBinding",
    "authentication"
})
public class RecoverRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "RecoverKeyBinding", required = true)
    protected KeyBindingType recoverKeyBinding = new KeyBindingType();
    @XmlElement(name = "Authentication", required = true)
    protected AuthenticationType authentication = new AuthenticationType();

    /**
     * Gets the value of the recoverKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link KeyBindingType }
     *     
     */
    public KeyBindingType getRecoverKeyBinding() {
        return recoverKeyBinding;
    }

    /**
     * Sets the value of the recoverKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link KeyBindingType }
     *     
     */
    public void setRecoverKeyBinding(KeyBindingType value) {
        this.recoverKeyBinding = value;
    }

    /**
     * Gets the value of the authentication property.
     * 
     * @return
     *     possible object is
     *     {@link AuthenticationType }
     *     
     */
    public AuthenticationType getAuthentication() {
        return authentication;
    }

    /**
     * Sets the value of the authentication property.
     * 
     * @param value
     *     allowed object is
     *     {@link AuthenticationType }
     *     
     */
    public void setAuthentication(AuthenticationType value) {
        this.authentication = value;
    }

}
